@@ -1,24 +1,36 @@
 """
 Dans_Diffraction
-Python package for loading crystal structures from cif files and calculating diffraction information
+Python package for loading crystal structures from cif files and calculating diffraction information.
+
+Installation:
+$ pip install Dans-Diffraction
+or
+$ git clone https://github.com/DanPorter/Dans_Diffraction.git
+
+Requirements:
+Python 2.7+/3+ with packages: Numpy, Matplotlib, Scipy, Tkinter
+BuiltIn packages used: sys, os, re, glob, warnings, json, itertools
 
 Usage:
-    ***In Python***
+    ***In Python/ script***
     import Dans_Diffraction as dif
     f = '/location/of/file.cif'
     xtl = dif.Crystal(f)
     
 Usage:
     ***From Terminal***
-    cd /location/of/file
-    ipython -i -m -matplotlib tk Dans_Diffraction
+    $ cd /location/of/file
+    $ ipython -i -m -matplotlib tk Dans_Diffraction
+
+GitHub Repo: https://github.com/DanPorter/Dans_Diffraction
+Citation DOI: https://doi.org/10.5281/zenodo.3859501
 
 By Dan Porter, PhD
 Diamond
 2017
 
-Version 1.8.2
-Last updated: 26/05/20
+Version 1.9.2
+Last updated: 16/05/20
 
 Version History:
 02/03/18 1.0    Version History started.
@@ -33,6 +45,9 @@ Version History:
 02/05/20 1.8    Updated readcif, added heavy atom properties, added magnetic spacegroups
 12/05/20 1.8.1  Updated readcif, added atomic_scattering_factors and classes_orbitals
 26/05/20 1.8.2  Updated copyright, removed tensor scattering. Updated magnetic spacegroups
+09/06/20 1.9    Chaneged magnetic symmetry calculation, now correctly generates mag symmetry from operations
+10/06/20 1.9.1  Added time symmetry to Symmetry class
+16/06/20 1.9.2  Made change in simpulate_powder to remove linspace error
 
 -----------------------------------------------------------------------------
    Copyright 2020 Diamond Light Source Ltd.
@@ -86,8 +101,8 @@ if fdmnes_checker():
     from .classes_fdmnes import Fdmnes, FdmnesAnalysis
 
 
-__version__ = '1.8.2'
-__date__ = '27/05/20'
+__version__ = '1.9.2'
+__date__ = '16/06/20'
 
 
 # Build
