@@ -165,13 +165,13 @@ def sf_neutron(hkl, uvw, occ, scatteringlength, debyewaller=1.0):
 
     hkl = np.asarray(hkl, dtype=np.float).reshape(-1, 3)
     uvw = np.asarray(uvw, dtype=np.float).reshape(-1, 3)
-    occ = np.asarray(occ, dtype=np.float).reshape(len(uvw), 1)
-    scatteringlength = np.asarray(scatteringlength, dtype=np.float).reshape(len(uvw), 1)
+    occ = np.asarray(occ, dtype=np.float).reshape(1, len(uvw))
+    scatteringlength = np.asarray(scatteringlength, dtype=np.float).reshape(1, len(uvw))
     debyewaller = np.asarray(debyewaller)
     if debyewaller.size == 1:
-        debyewaller = debyewaller * np.ones((len(uvw), len(hkl)))
+        debyewaller = debyewaller * np.ones((len(hkl), len(uvw)))
     else:
-        debyewaller = debyewaller.reshape(-1, len(hkl))
+        debyewaller = debyewaller.reshape(1, len(uvw))
 
     # Calculate dot product
     dot = np.dot(hkl, uvw.T)
@@ -322,8 +322,8 @@ def sf_magnetic_xray(q, r, occ, moment, magnetic_formfactor=None, debyewaller=1.
     return sf
 
 
-def xray_resonant(q, r, occ, moment, energy_kev=None, polarisation='sp', F0=1, F1=1, F2=1, azim_zero=[1, 0, 0], psi=0,
-                  disp=False):
+def sf_xray_resonant(q, r, occ, moment, energy_kev=None, polarisation='sp', F0=1, F1=1, F2=1, azi_ref_q=(1, 0, 0), psi=0,
+                  debyewaller=1.0):
     """
     Calculate structure factors using resonant scattering factors in the dipolar approximation
       I = Scattering.xray_resonant(HKL,energy_kev,polarisation,F0,F1,F2)
@@ -353,31 +353,25 @@ def xray_resonant(q, r, occ, moment, energy_kev=None, polarisation='sp', F0=1, F
     occ = np.asarray(occ, dtype=np.float).reshape((len(r), 1))
     moment = np.asarray(moment, dtype=np.float).reshape((-1, 3))
     psi = np.asarray(psi, dtype=np.float).reshape([-1])
+    npsi = len(psi)
 
     # Calculate dot product
-    dot_KR = np.dot(HKL, uvw.T)
+    dot = np.dot(q, r.T)
 
-    SF = np.zeros([Nref, Npsi], dtype=np.complex)
-    for psival in range(Npsi):
+    sf = np.zeros([len(q), npsi], dtype=np.complex)
+    for psival in range(npsi):
         # Get resonant form factor
-        fxres = self.xray_resonant_scattering_factor(HKL, energy_kev, polarisation, F0, F1, F2, azim_zero, PSI[psival],
-                                                     disp=disp)
+        fxres = xray_resonant_scattering_factor(q, moment, energy_kev, polarisation, F0, F1, F2, azi_ref_q, psi[psival])
 
         # Calculate structure factor
         # Broadcasting used on 2D fxres
-        SF[:, psival] = np.sum(fxres * dw * occ * np.exp(1j * 2 * np.pi * dot_KR), axis=1)
+        sf[:, psival] = np.sum(fxres * debyewaller * occ * np.exp(1j * 2 * np.pi * dot), axis=1)
 
-    SF = SF / xtl.scale
-
-    if self._return_structure_factor: return SF
-
-    # Calculate intensity
-    I = SF * np.conj(SF)
-    return np.real(I)
+    return sf
 
 
-def xray_resonant_scattering_factor(xtl, HKL, energy_kev=None, polarisation='sp', F0=1, F1=1, F2=1,
-                                    azim_zero=[1, 0, 0], psi=0, disp=False):
+def xray_resonant_scattering_factor(q, moment, energy_kev=None, polarisation='sp', F0=1, F1=1, F2=1, psi=0,
+                                    azi_ref_q=(1, 0, 0)):
     """
     Calcualte fxres, the resonant x-ray scattering factor
       fxres = Scattering.xray_resonant_scattering_factor(HKL,energy_kev,polarisation,F0,F1,F2,azim_zero,psi)
@@ -387,6 +381,18 @@ def xray_resonant_scattering_factor(xtl, HKL, energy_kev=None, polarisation='sp'
         azim_zero = [h,k,l] vector parallel to the origin of the azimuth {[1,0,0]}
         psi = azimuthal angle defining the scattering plane {0}
 
+    :param q: [n*3] array of reflection coordinates in cartesian basis (Q)
+    :param moment: [mx3] array of magnetic moments in cartesian basis
+    :param energy_kev: float energy in keV
+    :param polarisation: polarisation condition: 'sp', 'ss', 'ps', 'pp'. s=sigma, p=pi
+    :param F0: 1/0 Resonance factor Flm
+    :param F1: 1/0 Resonance factor Flm
+    :param F2: 1/0 Resonance factor Flm
+    :param azi_ref_q: azimuthal refence, in cartesian basis (Q)
+    :param psi: float, azimuthal angle
+    :param disp: False*/True display scattering components
+    :return: fxres [n*1] array of resonant x-ray scattering factors
+
     Uses the E1E1 resonant x-ray scattering amplitude:
         fxr_n = (ef.ei)*F0 -i(ef X ei).z_n*F1 + (ef.z_n)(ei.z_n)F2
 
@@ -401,67 +407,58 @@ def xray_resonant_scattering_factor(xtl, HKL, energy_kev=None, polarisation='sp'
     From Hill+McMorrow Acta Cryst. 1996 A52, 236-244 Equ. (15)
     """
 
-    if energy_kev is None:
-        energy_kev = self._energy_kev
+    q = np.asarray(q, dtype=np.float).reshape((-1, 3))
+    moment = np.asarray(moment, dtype=np.float).reshape((-1, 3))
+    nref = len(q)
+    nat = len(moment)
 
-    HKL = np.asarray(np.rint(HKL), dtype=np.float).reshape([-1, 3])
-    Nref = len(HKL)
-    Qmag = xtl.Cell.Qmag(HKL)
-    tth = fc.cal2theta(Qmag, energy_kev)
+    qmag = fg.mag(q)
+    tth = fc.cal2theta(qmag, energy_kev)
 
-    mxmymz = xtl.Structure.mxmymz()
-    Nat = len(mxmymz)
-
-    fxres = np.zeros([Nref, Nat], dtype=np.complex)
-    for ref in range(Nref):
+    fxres = np.zeros([nref, nat], dtype=np.complex)
+    for ref in range(nref):
         # Resonant scattering factor
         # Electric Dipole transition at 3d L edge
         # F0,F1,F2 = 1,1,1 # Flm (form factor?)
-        z1, z2, z3 = self.scatteringcomponents(mxmymz, HKL[ref], azim_zero, psi).T
+        z1, z2, z3 = scatteringcomponents(moment, q[ref], azi_ref_q, psi).T
         tthr = np.deg2rad(tth[ref])
 
-        polarisation = polarisation.replace('-', '').replace(' ', '')
+        polarisation = polarisation.lower().replace('-', '').replace(' ', '')
         if polarisation in ['sigmasigma', 'sigsig', 'ss']:  # Sigma-Sigma
-            f0 = 1 * np.ones(Nat)
-            f1 = 0 * np.ones(Nat)
+            f0 = 1 * np.ones(nat)
+            f1 = 0 * np.ones(nat)
             f2 = z2 ** 2
         elif polarisation in ['sigmapi', 'sigpi', 'sp']:  # Sigma-Pi
-            f0 = 0 * np.ones(Nat)
+            f0 = 0 * np.ones(nat)
             f1 = z1 * np.cos(tthr) + z3 * np.sin(tthr)
             f2 = -z2 * (z1 * np.sin(tthr) - z3 * np.cos(tthr))
         elif polarisation in ['pisigma', 'pisig', 'ps']:  # Pi-Sigma
-            f0 = 0 * np.ones(Nat)
+            f0 = 0 * np.ones(nat)
             f1 = z3 * np.sin(tthr) - z1 * np.cos(tthr)
             f2 = z2 * (z1 * np.sin(tthr) + z3 * np.cos(tthr))
         elif polarisation in ['pipi', 'pp']:  # Pi-Pi
-            f0 = np.cos(2 * tthr) * np.ones(Nat)
+            f0 = np.cos(2 * tthr) * np.ones(nat)
             f1 = -z2 * np.sin(2 * tthr)
             f2 = -(np.cos(tthr) ** 2) * (z1 ** 2 * np.tan(tthr) ** 2 + z3 ** 2)
         else:
             raise ValueError('Incorrect polarisation. pol should be e.g. ''ss'' or ''sp''')
         fxres[ref, :] = F0 * f0 - 1j * F1 * f1 + F2 * f2
-        if disp:
-            print('( h, k, l)   TTH  (    mx,    my,    mz)  (    z1,    z2,    z3)')
-            fmt = '(%2.0f,%2.0f,%2.0f) %6.2f  (%6.3f,%6.3f,%6.3f)  (%6.3f,%6.3f,%6.3f)  f0=%8.4f  f1=%8.4f  f2=%8.4f fxres= (%8.4f + %8.4fi)'
-            for at in range(Nat):
-                vals = (HKL[ref, 0], HKL[ref, 1], HKL[ref, 2], tth[ref],
-                        mxmymz[at, 0], mxmymz[at, 1], mxmymz[at, 2],
-                        z1[at], z2[at], z3[at],
-                        f0[at], f1[at], f2[at],
-                        fxres[ref, at].real, fxres[ref, at].imag)
-                print(fmt % vals)
     return fxres
 
 
-def scatteringcomponents(xtl, mxmymz, hkl, azim_zero=[1, 0, 0], psi=0):
+def scatteringcomponents(moment, q, azi_ref_q=(1, 0, 0), psi=0):
     """
     Transform magnetic vector into components within the scattering plane
-        ***warning - may not be correct for non-cubic systems***
+    :param moment: [n*3] array of magnetic moments in a cartesian basis
+    :param q: [1*3] reflection vector in a cartesian basis
+    :param azi_ref_q: [1*3] azimuthal reference in a cartesian basis
+    :param psi: float azimuthal angle
+    :return: (z1, z2, z3) components of the magnetic moment along the reflection direction
     """
 
     # Define coordinate system I,J,Q (U1,U2,U3)
-    Qhat = fg.norm(xtl.xtl.Cell.calculateQ(hkl))  # || Q
-    AxQ = fg.norm(np.cross(azim_zero, Qhat))
+    Qhat = fg.norm(q)  # || Q
+    AxQ = fg.norm(np.cross(azi_ref_q, Qhat))
     Ihat = fg.norm(np.cross(Qhat, AxQ))  # || to azim_zero
     Jhat = fg.norm(np.cross(Qhat, Ihat))  # -| to I and Q
 
@@ -471,7 +468,7 @@ def scatteringcomponents(xtl, mxmymz, hkl, azim_zero=[1, 0, 0], psi=0):
 
     # Determine components of the magnetic vector
     U = np.vstack([Ihat_psi, Jhat_psi, Qhat])
-    z1z2z3 = np.dot(mxmymz, U.T)  # [mxmymz.I, mxmymz.J, mxmymz.Q]
+    z1z2z3 = np.dot(moment, U.T)  # [mxmymz.I, mxmymz.J, mxmymz.Q]
     return fg.norm(z1z2z3)
 
 
